@@ -8,13 +8,14 @@
 #
 #############################################################################
 #
+# $Id: bump_version.pl 1055 2008-05-21 02:57:17Z mbr $
+#
 
 use strict;
 
-my @files = (qw(
+my @files = qw(
     fwsnort
-    README
-));
+);
 
 my $new_version = $ARGV[0] or die "[*] $0 <new version>";
 
